@@ -13,6 +13,11 @@ INSTRUCTIONS = {
         "sudo adduser saned plugdev\n"
         "sudo adduser saned scanner\n"
         "sudo adduser saned lp\n"
+        "# reboot\n"
+        "\n"
+        "# If your scanner is still not recognized, please check\n"
+        "# https://gitlab.gnome.org/World/OpenPaperwork/paperwork/-/blob"
+        "/develop/doc/install.flatpak.markdown#faq\n"
     ),
     'Fedora / CentOS / RHEL / …': (
         "sudo dnf install libinsane sane-backends-daemon\n"
@@ -50,22 +55,19 @@ class Plugin(openpaperwork_core.PluginBase):
             },
         ]
 
-    def init(self, core):
-        super().init(core)
-
-        if self.core.call_success("is_in_flatpak") is None:
-            return
+    def settings_scanner_get_extra_widget(self):
+        if not self.core.call_success("is_in_flatpak"):
+            return None
 
         widget_tree = self.core.call_success(
             "gtk_load_widget_tree", "paperwork_gtk.settings.scanner",
             "flatpak.glade"
         )
         if widget_tree is None:
-            return
-
+            return None
         button = widget_tree.get_object("button_flatpak_info")
-        self.core.call_all("settings_scanner_set_extra_widget", button)
         button.connect("clicked", self._on_clicked)
+        return button
 
     def on_gtk_window_opened(self, window):
         self.windows.append(window)
